==> qtjambi-network-debuginfo-macos-6.6.0.jar: sources/QtJambiNetwork/QAbstractNetworkCache_shell.h <==
#ifndef QABSTRACTNETWORKCACHE_SHELL_H
#define QABSTRACTNETWORKCACHE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtNetwork/qabstractnetworkcache.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QAbstractNetworkCache_shell : public QAbstractNetworkCache, public QtJambiShellInterface
{
public:
    QAbstractNetworkCache_shell(QObject* parent0 = nullptr);
    ~QAbstractNetworkCache_shell() override;

    qint64 cacheSize() const override;
    void childEvent(QChildEvent* event0) override;
    void clear() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QIODevice* data(const QUrl& url0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void insert(QIODevice* device0) override;
    QNetworkCacheMetaData metaData(const QUrl& url0) override;
    QIODevice* prepare(const QNetworkCacheMetaData& metaData0) override;
    bool remove(const QUrl& url0) override;
    void timerEvent(QTimerEvent* event0) override;
    void updateMetaData(const QNetworkCacheMetaData& metaData0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractNetworkCache_access : public QAbstractNetworkCache
{
    jlong __qt_cacheSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_clear(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_data_cref_QUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0);
    void __qt_insert_QIODevice_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID device0);
    jobject __qt_metaData_cref_QUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0);
    jobject __qt_prepare_cref_QNetworkCacheMetaData(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID metaData0);
    jboolean __qt_remove_cref_QUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0);
    void __qt_updateMetaData_cref_QNetworkCacheMetaData(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID metaData0);
};

#endif // QABSTRACTNETWORKCACHE_SHELL_H

==> qtjambi-network-debuginfo-macos-6.6.2.jar: sources/QtJambiNetwork/QAbstractNetworkCache_shell.h <==
#ifndef QABSTRACTNETWORKCACHE_SHELL_H
#define QABSTRACTNETWORKCACHE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtNetwork/qabstractnetworkcache.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QAbstractNetworkCache_shell : public QAbstractNetworkCache, public QtJambiShellInterface
{
public:
    QAbstractNetworkCache_shell(QObject* parent0 = nullptr);
    ~QAbstractNetworkCache_shell() override;

    qint64 cacheSize() const override;
    void childEvent(QChildEvent* event0) override;
    void clear() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QIODevice* data(const QUrl& url0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void insert(QIODevice* device0) override;
    QNetworkCacheMetaData metaData(const QUrl& url0) override;
    QIODevice* prepare(const QNetworkCacheMetaData& metaData0) override;
    bool remove(const QUrl& url0) override;
    void timerEvent(QTimerEvent* event0) override;
    void updateMetaData(const QNetworkCacheMetaData& metaData0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractNetworkCache_access : public QAbstractNetworkCache
{
    jlong __qt_cacheSize_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_clear(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_data_cref_QUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0);
    void __qt_insert_QIODevice_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID device0);
    jobject __qt_metaData_cref_QUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0);
    jobject __qt_prepare_cref_QNetworkCacheMetaData(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID metaData0);
    jboolean __qt_remove_cref_QUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0);
    void __qt_updateMetaData_cref_QNetworkCacheMetaData(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID metaData0);
};

#endif // QABSTRACTNETWORKCACHE_SHELL_H
